@@ -78,11 +78,13 @@ colSpeed="springgreen3"; colForce="blue2"; colPower="tomato2"	#colors
 cols=c(colSpeed,colForce,colPower); lty=rep(1,3)	
 
 
+
+
 #--- user commands ---
 #way A. passing options to a file
 getOptionsFromFile <- function(optionsFile) {
 	optionsCon <- file(optionsFile, 'r')
-	options=readLines(optionsCon,n=27)
+	options=readLines(optionsCon,n=29)
 	close(optionsCon)
 	return (options)
 }
@@ -108,79 +110,6 @@ EncoderConfigurationName = ""
 
 write("(1/5) Starting R", OutputData2)
 
-#extrema function is part of EMD package
-#It's included here to save time, because 'library("EMD")' is quite time consuming
-extrema <- function(y, ndata = length(y), ndatam1 = ndata - 1) {
-
-	minindex <- maxindex <- NULL; nextreme <- 0; cross <- NULL; ncross <- 0 
-
-	z1 <- sign(diff(y))
-	index1 <- seq(1, ndatam1)[z1 != 0]; z1 <- z1[z1 != 0]  
-
-	if (!(is.null(index1) || all(z1==1) || all(z1==-1))) {
-
-		index1 <- index1[c(z1[-length(z1)] != z1[-1], FALSE)] + 1 
-		z1 <- z1[c(z1[-length(z1)] != z1[-1], FALSE)]  
-
-		nextreme <- length(index1)
-
-		if(nextreme >= 2)
-			for(i in 1:(nextreme-1)) {
-				tmpindex <- index1[i]:(index1[i+1]-1)
-				if(z1[i] > 0) {
-					tmpindex <- tmpindex[y[index1[i]] == y[tmpindex]]
-					maxindex <- rbind(maxindex, c(min(tmpindex), max(tmpindex)))
-				} else {
-					tmpindex <- tmpindex[y[index1[i]] == y[tmpindex]]
-					minindex <- rbind(minindex, c(min(tmpindex), max(tmpindex)))
-				}     
-			} 
-
-		tmpindex <- index1[nextreme]:ndatam1  
-		if(z1[nextreme] > 0) {
-			tmpindex <- tmpindex[y[index1[nextreme]] == y[tmpindex]]
-			maxindex <- rbind(maxindex, c(min(tmpindex), max(tmpindex)))
-		} else {
-			tmpindex <- tmpindex[y[index1[nextreme]] == y[tmpindex]]
-			minindex <- rbind(minindex, c(min(tmpindex), max(tmpindex)))
-		}  
-
-		### Finding the index of zero crossing  
-
-		if (!(all(sign(y) >= 0) || all(sign(y) <= 0) || all(sign(y) == 0))) {
-			index1 <- c(1, index1)
-			for (i in 1:nextreme) {
-				if (y[index1[i]] == 0) {
-					tmp <- c(index1[i]:index1[i+1])[y[index1[i]:index1[i+1]] == 0]
-					cross <- rbind(cross, c(min(tmp), max(tmp)))                 
-				} else
-					if (y[index1[i]] * y[index1[i+1]] < 0) {
-						tmp <- min(c(index1[i]:index1[i+1])[y[index1[i]] * y[index1[i]:index1[i+1]] <= 0])
-						if (y[tmp] == 0) {
-							tmp <- c(tmp:index1[i+1])[y[tmp:index1[i+1]] == 0]
-							cross <- rbind(cross, c(min(tmp), max(tmp))) 
-						} else 
-							cross <- rbind(cross, c(tmp-1, tmp)) 
-					}
-			}
-			#if (y[ndata] == 0) {
-			#    tmp <- c(index1[nextreme+1]:ndata)[y[index1[nextreme+1]:ndata] == 0]
-			#    cross <- rbind(cross, c(min(tmp), max(tmp)))         
-			#} else
-			if (any(y[index1[nextreme+1]] * y[index1[nextreme+1]:ndata] <= 0)) {
-				tmp <- min(c(index1[nextreme+1]:ndata)[y[index1[nextreme+1]] * y[index1[nextreme+1]:ndata] <= 0])
-				if (y[tmp] == 0) {
-					tmp <- c(tmp:ndata)[y[tmp:ndata] == 0]
-					cross <- rbind(cross, c(min(tmp), max(tmp))) 
-				} else
-					cross <- rbind(cross, c(tmp-1, tmp))
-			}
-			ncross <- nrow(cross)        
-		}
-	} 
-
-	list(minindex=minindex, maxindex=maxindex, nextreme=nextreme, cross=cross, ncross=ncross)
-}    
 
 # This function converts top curve into bottom curve
 #
@@ -236,7 +165,8 @@ extrema <- function(y, ndata = length(y), ndatam1 = ndata - 1) {
 #this methods replaces getDisplacement and fixRawdataInertial
 #here comes a signal: (singleFile)
 #it shows the disc rotation and the person movement
-getDisplacementInertial <- function(displacement, draw, title) {
+getDisplacementInertialBody <- function(displacement, draw, title) 
+{
 	position=cumsum(displacement)
 	position.ext=extrema(position)
 
@@ -253,6 +183,10 @@ getDisplacementInertial <- function(displacement, draw, title) {
 	firstDownPhaseTime = position.ext$minindex[1]
 
 	downHeight = abs(position[1] - position[firstDownPhaseTime])
+		
+	positionPerson = abs(cumsum(displacement))*-1
+	#this is to make "inverted cumsum"
+	displacementPerson = c(0,diff(positionPerson))
 	
 	if(draw) {
 		col="black"
@@ -265,9 +199,6 @@ getDisplacementInertial <- function(displacement, draw, title) {
 
 		abline(h=0, lty=2, col="gray")
 	
-		positionPerson = abs(cumsum(displacement))*-1
-		#this is to make "inverted cumsum"
-		displacementPerson = c(0,diff(positionPerson))
 		lines((1:length(position))/1000,positionPerson/10,lty=1,lwd=2)
 		
 		title(title, cex.main=1, font.main=1)
@@ -461,7 +392,7 @@ findSmoothingsEC <- function(displacement, curves, eccon, smoothingOneC) {
 				speed <- getSpeed(eccentric.concentric, j)
 				smoothingOneEC = j
 				maxSpeedEC=max(speed$y)
-				print(c("maxC",maxSpeedC,"maxEC",maxSpeedEC))
+				print(c("j",j,"maxC",round(maxSpeedC,3),"maxEC",round(maxSpeedEC,3)))
 				if(maxSpeedEC >= maxSpeedC)
 					break
 			}
@@ -477,13 +408,21 @@ findSmoothingsEC <- function(displacement, curves, eccon, smoothingOneC) {
 }
 
 #used in alls eccons
-reduceCurveBySpeed <- function(eccon, row, startT, displacement, smoothingOneEC, smoothingOneC) 
+reduceCurveBySpeed <- function(eccon, row, startT, displacement, smoothingOneC) 
 {
 	print("at reduceCurveBySpeed")
 
-	smoothing = smoothingOneEC
-	if(eccon == "c" || eccon == "ecS" || eccon == "ceS")
-		smoothing = smoothingOneC
+	#In 1.4.0 and before, we use smoothingOneEC on "ec", "ce"
+	#but the problem is findSmoothingsEC has problems knowing the smoothingEC when users stays stand up lot of time before jump.
+        #is better to reduceCurveBySpeed first in order to remove the not-moving phase
+	#and then do findSmoothingsEC
+	#for this reason, following code is commented, and it's only used smoothingOneC	
+
+	#smoothing = smoothingOneEC
+	#if(eccon == "c" || eccon == "ecS" || eccon == "ceS")
+	#	smoothing = smoothingOneC
+		
+	smoothing = smoothingOneC
 
 	speed <- getSpeed(displacement, smoothing)
 	
@@ -604,12 +543,12 @@ findECPhases <- function(displacement,speed) {
 	isometricUse = TRUE
 	if(isometricUse) {
 		eccentric=1:min(speed.ext$cross[crossMinRow,1])
-		isometric=c(min(speed.ext$cross[crossMinRow,1]), max(speed.ext$cross[crossMinRow,2]))
-		concentric=max(speed.ext$cross[crossMinRow,2]):length(displacement)
+		isometric=min(speed.ext$cross[crossMinRow,1]+1):max(speed.ext$cross[crossMinRow,2])
+		concentric=max(speed.ext$cross[crossMinRow,2]+1):length(displacement)
 	} else {
 		eccentric=1:mean(speed.ext$cross[crossMinRow,1])
-		isometric=c(mean(speed.ext$cross[crossMinRow,1]), mean(speed.ext$cross[crossMinRow,2]))
-		concentric=mean(speed.ext$cross[crossMinRow,2]):length(displacement)
+		#isometric=mean(speed.ext$cross[crossMinRow,1]+1):mean(speed.ext$cross[crossMinRow,2])
+		concentric=mean(speed.ext$cross[crossMinRow,2]+1):length(displacement)
 	}
 	return(list(
 		eccentric=eccentric,
@@ -624,7 +563,7 @@ findECPhases <- function(displacement,speed) {
 #Also use more this funcion (eg on paint)
 findPropulsiveEnd <- function(accel, concentric) {
 	if(length(which(accel[concentric]<=-g)) > 0) 
-		propulsiveEnd = min(concentric) + min(which(accel[concentric] <= -g))
+		propulsiveEnd = min(which(accel[concentric] <= -g))
 	else
 		propulsiveEnd = max(concentric)
 	
@@ -746,7 +685,7 @@ pafGenerate <- function(eccon, kinematics, massBody, massExtra) {
 
 kinematicRanges <- function(singleFile, displacement, curves,
 			    massBody, massExtra, exercisePercentBodyWeight,
-			    encoderConfiguration,diameter,diameterExt,anglePush,angleWeight,inertiaMomentum,gearedDown,
+			    encoderConfigurationName,diameter,diameterExt,anglePush,angleWeight,inertiaMomentum,gearedDown,
 			    smoothingsEC, smoothingOneC, g, eccon, isPropulsive) {
 	n=length(curves[,1])
 	maxSpeedy=0; maxAccely=0; maxForce=0; maxPower=0
@@ -757,7 +696,7 @@ kinematicRanges <- function(singleFile, displacement, curves,
 		myExPercentBodyWeight = exercisePercentBodyWeight
 			
 		#encoderConfiguration
-		myEncoderConfigurationName = EncoderConfigurationName
+		myEncoderConfigurationName = encoderConfigurationName
 		myDiameter = diameter
 		myDiameterExt = diameterExt
 		myAnglePush = anglePush
@@ -779,6 +718,7 @@ kinematicRanges <- function(singleFile, displacement, curves,
 			myInertiaMomentum = curves[i,16]
 			myGearedDown = curves[i,17]
 		}
+
 		kn=kinematicsF(displacement[curves[i,1]:curves[i,2]],
 			       myMassBody, myMassExtra, myExPercentBodyWeight,
 			       myEncoderConfigurationName,myDiameter,myDiameterExt,myAnglePush,myAngleWeight,myInertiaMomentum,myGearedDown,
@@ -936,6 +876,7 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 	eccentric=0
 	isometric=0
 	concentric=0
+
 	if(eccon=="c") {
 		concentric=1:length(displacement)
 	} else {	#"ec", "ce". Eccons "ecS" and "ceS" are not painted
@@ -961,12 +902,12 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 		#TODO: con-ecc is opposite
 		if(isometricUse) {
 			eccentric=1:min(speed.ext$cross[crossMinRow,1])
-			isometric=c(min(speed.ext$cross[crossMinRow,1]), max(speed.ext$cross[crossMinRow,2]))
-			concentric=max(speed.ext$cross[crossMinRow,2]):length(displacement)
+			isometric=c(min(speed.ext$cross[crossMinRow,1]+1), max(speed.ext$cross[crossMinRow,2]))
+			concentric=max(speed.ext$cross[crossMinRow,2]+1):length(displacement)
 		} else {
 			eccentric=1:mean(speed.ext$cross[crossMinRow,1])
-			isometric=c(mean(speed.ext$cross[crossMinRow,1]), mean(speed.ext$cross[crossMinRow,2]))
-			concentric=mean(speed.ext$cross[crossMinRow,2]):length(displacement)
+			#isometric=c(mean(speed.ext$cross[crossMinRow,1]+1), mean(speed.ext$cross[crossMinRow,2]))
+			concentric=mean(speed.ext$cross[crossMinRow,2]+1):length(displacement)
 		}
 
 		if(draw) {
@@ -1000,7 +941,7 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 
 	#propulsive phase ends when accel is -9.8
 	if(length(which(accel$y[concentric]<=-g)) > 0 & isPropulsive) {
-		propulsiveEnd = min(concentric) + min(which(accel$y[concentric]<=-g))
+		propulsiveEnd = min(which(accel$y[concentric]<=-g))
 	} else {
 		propulsiveEnd = max(concentric)
 	}
@@ -1066,7 +1007,8 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 		if(isPropulsive) {
 			#propulsive stuff
 			segments(0,-9.81,length(accel$y),-9.81,lty=3,col="magenta")
-			abline(v=propulsiveEnd,lty=3,col="magenta") 
+			#abline(v=propulsiveEnd,lty=3,col="magenta") 
+			abline(v=propulsiveEnd,lty=1,col=cols[2]) 
 			points(propulsiveEnd, -g, col="magenta")
 			text(x=length(accel$y),y=-9.81,labels=" g",cex=1,adj=c(0,0),col="magenta")
 		}
@@ -1085,6 +1027,7 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 	force = dynamics$force
 	power = dynamics$power
 
+
 #print(c(knRanges$accely, max(accel$y), min(accel$y)))
 #	force <- mass*accel$y
 #	if(isJump)
@@ -1116,19 +1059,44 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 	#but this eccon will be not done
 	#if(draw & (!superpose || (superpose & highlight)) & isJump) 
 	if(draw & (!superpose || (superpose & highlight)) & exercisePercentBodyWeight == 100) {
-		weight=mass*9.81
+		weight=mass*g
 		abline(h=weight,lty=1,col=cols[2]) #body force, lower than this, person in the air (in a jump)
-		takeoff = max(which(force>=weight))
+
+		#define like this, because if eccentric == 0, length(eccentric) == 1
+		#and if eccentric is NULL, then length(eccentric == 0), but max(eccentric) produces error
+		if(eccentric == 0)
+			length_eccentric = 0
+		else
+			length_eccentric = length(eccentric)
+
+		if(isometric == 0)
+			length_isometric = 0
+		else
+			length_isometric = length(isometric)
+
+
+		#takeoff = max(which(force>=weight))
+		#takeoff = min(which(force[concentric]<=weight)) + length_eccentric + length_isometric
+		takeoff = min(which(force[concentric]<=0)) + length_eccentric + length_isometric
 		abline(v=takeoff,lty=1,col=cols[2]) 
 		mtext(text="land ",side=3,at=takeoff,cex=.8,adj=1,col=cols[2])
 		mtext(text=" air ",side=3,at=takeoff,cex=.8,adj=0,col=cols[2])
 		text(x=length(force),y=weight,labels="Weight (N)",cex=.8,adj=c(.5,0),col=cols[2])
+
 		if(eccon=="ec") {
-			landing = min(which(force>=weight))
+			#landing = min(which(force>=weight))
+			landing = max(which(force[eccentric]<=weight))
 			abline(v=landing,lty=1,col=cols[2]) 
 			mtext(text="air ",side=3,at=landing,cex=.8,adj=1,col=cols[2])
 			mtext(text=" land ",side=3,at=landing,cex=.8,adj=0,col=cols[2])
 		}
+		
+		mtext(text=paste("jump height =", 
+				 (position[concentric[length(concentric)]] - 
+				  position[concentric[(takeoff - length_eccentric - length_isometric)]])/10,
+				 "cm",sep=" "),
+		      side=3, at=( takeoff + (length_eccentric + length(concentric)) )/2,
+		      cex=.8,adj=0.5,col=cols[2])
 	}
 	#forceToBodyMass <- force - weight
 	#force.ext=extrema(forceToBodyMass)
@@ -1803,6 +1771,32 @@ getDisplacement <- function(encoderConfigurationName, data, diameter, diameterEx
 	return(data)
 }
 
+fixDisplacementInertial <- function(displacement, encoderConfigurationName, diameter, diameterExt)
+{
+	#scanned displacement is ticks of rotary axis encoder
+	#now convert it to mm of body displacement
+	if(encoderConfigurationName == "ROTARYAXISINERTIAL") {
+		displacementMeters = displacement / 1000 #mm -> m
+		diameterMeters = diameter / 100 #cm -> m
+
+		ticksRotaryEncoder = 200 #our rotary axis encoder send 200 ticks by turn
+		#angle in radians
+		angle = abs(cumsum(displacementMeters * 1000)) * 2 * pi / ticksRotaryEncoder
+		position = angle * diameterMeters / 2
+		position = position * 1000	#m -> mm
+		#this is to make "inverted cumsum"
+		displacement = c(0,diff(position)) #this displacement is going to be used now
+	}
+
+	#on friction side: know displacement of the "person"
+	if(encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIAL")
+	{
+		displacement = displacement * diameter / diameterExt #displacement of the axis
+	}
+
+	return (displacement)
+}
+
 getSpeed <- function(displacement, smoothing) {
 	#no change affected by encoderConfiguration
 
@@ -1893,67 +1887,51 @@ getDynamicsNotInertial <- function(encoderConfigurationName, speed, accel, mass,
 
 getDynamicsInertial <- function(encoderConfigurationName, displacement, d, D, mass, inertiaMomentum, smoothing)
 {
-displacement = displacement / 1000 #mm -> m
-d=d/100 #cm -> m
-D=D/100 #cm -> m
-	if(encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIAL")
-	{
-		angle = displacement * 2 / D #displacement of the disc
-		displacement = displacement * d / D #displacement of the axis
-	}
+	speed = getSpeed(displacement, smoothing) #mm/ms == m/s 
 
-	#position = abs(cumsum(displacement)) / 1000 #mm -> m
-	position = abs(cumsum(displacement))
+	# accel will be:
+	accel = getAcceleration(speed) 
 
-	if(encoderConfigurationName == "LINEARINERTIAL" ||
-	   encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIAL" ||
-	   encoderConfigurationName == "ROTARYFRICTIONAXISINERTIAL") {
+	accel$y = accel$y * 1000 # mm/ms² -> m/s²
+	
+	#use the values
+	speed = speed$y
+	accel = accel$y
+	
+	#----------------------
+	#let's work with SI now
+	#----------------------
 
-		speed = getSpeed(displacement, smoothing)  # getSpeed returns in m/ms because displacement is in m/ms
-		speed$y = speed$y * 1000 # m/ms -> m/s
-		accel = getAcceleration(speed) # getAcceleration returns in m/ms²
-		accel$y = accel$y * 1000000 # m/ms² -> m/s²
-		#use the values
-		speed = speed$y
-		accel = accel$y
+	position.m = abs(cumsum(displacement)) / 1000 #m
+	d.m = d / 100 #cm -> m
+	D.m = D / 100 #cm -> m
 
-		angle = position * 2 / d
-		angleSpeed = speed * 2 / d
-		angleAccel = accel * 2 / d
-	} else {
-		#(encoderConfigurationName == "ROTARYAXISINERTIAL")
-		ticksRotaryEncoder = 200 #our rotary axis encoder send 200 ticks by turn
-#revisar		angle = abs(cumsum(displacement)) * 2 * pi / ticksRotaryEncoder
+	angle = position.m * 2 / d.m
+	angleSpeed = speed * 2 / d.m
+	angleAccel = accel * 2 / d.m
 
-		angleSpeed = getSpeed(angle, smoothing)
-		angleAccel = getAcceleration(angleSpeed)      
-		#use the values
-		angleSpeed = angleSpeed$y
-		angleAccel = angleAccel$y
-
-		position = angle * d / 2
-		speed = angleSpeed * d / 2
-		accel = angleAccel * d / 2
-	}
-
-	force = abs(inertiaMomentum * angleAccel) * (2 / d) + mass * (accel + g)
+	force = abs(inertiaMomentum * angleAccel) * (2 / d.m) + mass * (accel + g)
 	power = abs((inertiaMomentum * angleAccel) * angleSpeed) + mass * (accel + g) * speed
 	powerBody = mass * (accel + g) * speed
 	powerWheel = abs((inertiaMomentum * angleAccel) * angleSpeed)
 
 	#print(c("displacement",displacement))
-	#print(c("inertia momentum",inertiaMomentum))
+	#print(c("displacement cumsum",cumsum(displacement)))
+	print(c("inertia momentum",inertiaMomentum))
         #print(c("d",d))
         #print(c("mass",mass))
         #print(c("g",g))
-	#print(c("angleAccel",angleAccel))
-	#print(c("angleSpeed",angleSpeed))
+        print(c("max angle",max(abs(angle))))
+	print(c("max angleSpeed",max(abs(angleSpeed))))
+	print(c("max angleAccel",max(abs(angleAccel))))
 	#print(c("speed",speed))
 	#print(c("accel",accel))
-	#print(c("force",force))
-	#print(c("power at inertial",power))
+	print(c("max force",max(abs(force))))
+	print(c("max power at inertial",max(abs(power))))
 	#print(c("powerBody",powerBody[1000]))
 	#print(c("powerWheel",powerWheel[1000]))
+	print(c("d.m, D.m", d.m, D.m))
+	print(c("max angle, max pos", max(angle), max(position.m)))
 
 	return(list(displacement=displacement, mass=mass, force=force, power=power))
 }
@@ -2027,6 +2005,14 @@ doProcess <- function(options) {
 	OperatingSystem=options[27]	#if this changes, change it also at start of this R file
 	#IMPORTANT, if this grows, change the readLines value on getOptionsFromFile
 
+	scriptOne = options[28] #usually util.R
+	scriptTwo = options[29] #usually neuromuscularProfile.R
+	#--- include files ---
+	if(scriptOne != "none")
+		source(scriptOne)
+	if(scriptTwo != "none")
+		source(scriptTwo)
+
 	print(File)
 	print(OutputGraph)
 	print(OutputData1)
@@ -2136,7 +2122,12 @@ doProcess <- function(options) {
 			#this removes all NAs on a curve
 			dataTempFile  = dataTempFile[!is.na(dataTempFile)]
 
-			dataTempFile = getDisplacement(inputMultiData$econfName[i], dataTempFile, diameter, diameterExt)
+			if(isInertial(inputMultiData$econfName[i])) {
+				dataTempFile = fixDisplacementInertial(dataTempFile, inputMultiData$econfName[i], diameter, diameterExt)
+			} else {
+				dataTempFile = getDisplacement(inputMultiData$econfName[i], dataTempFile, diameter, diameterExt)
+			}
+
 
 			dataTempPhase=dataTempFile
 			processTimes = 1
@@ -2179,7 +2170,7 @@ doProcess <- function(options) {
 				econfD[(i+newLines)] = inputMultiData$econfD[i]
 				econfAnglePush[(i+newLines)] = inputMultiData$econfAnglePush[i]
 				econfAngleWeight[(i+newLines)] = inputMultiData$econfAngleWeight[i]
-				econfInertia[(i+newLines)] = inputMultiData$econfInertia[i]
+				econfInertia[(i+newLines)] = inputMultiData$econfInertia[i]/10000.0 #comes in Kg*cm^2 eg: 100; convert it to Kg*m^2 eg: 0.010
 				econfGearedDown[(i+newLines)] = inputMultiData$econfGearedDown[i]
 
 				curvesHeight[(i+newLines)] = sum(dataTempPhase)
@@ -2243,8 +2234,12 @@ doProcess <- function(options) {
 		#this removes all NAs
 		displacement  = displacement[!is.na(displacement)]
 
-		if(isInertial(EncoderConfigurationName)) {
-			displacement = getDisplacementInertial(displacement, curvesPlot, Title)
+		if(isInertial(EncoderConfigurationName)) 
+		{
+			displacement = fixDisplacementInertial(displacement, EncoderConfigurationName, diameter, diameterExt)
+			
+			displacement = getDisplacementInertialBody(displacement, curvesPlot, Title)
+
 			curvesPlot = FALSE
 		} else {
 			displacement = getDisplacement(EncoderConfigurationName, displacement, diameter, diameterExt)
@@ -2257,31 +2252,41 @@ doProcess <- function(options) {
 			write("", OutputData1)
 			quit()
 		}
+			
+		position=cumsum(displacement)
 
+		#print(c("position",position))
+		#print(c("displacement",displacement))
+		
 		curves=findCurves(displacement, Eccon, MinHeight, curvesPlot, Title)
 
 		if(Analysis == "curves")
 			curvesPlot = TRUE
 
-		position=cumsum(displacement)
-
 		n=length(curves[,1])
 		quitIfNoData(n, curves, OutputData1)
+		
+		print("curves before reduceCurveBySpeed")
+		print(curves)
 	
+		#reduceCurveBySpeed, don't do in inertial because it doesn't do a good right adjust on changing phase
+		#what reduceCurveBySpeed is doing in inertial is adding a value at right, and this value is a descending value
+		#and this produces a high acceleration there
+		if( ! isInertial(EncoderConfigurationName)) {
+			for(i in 1:n) {
+				reduceTemp=reduceCurveBySpeed(Eccon, i, curves[i,1], displacement[curves[i,1]:curves[i,2]], SmoothingOneC)
+				curves[i,1] = reduceTemp[1]
+				curves[i,2] = reduceTemp[2]
+			}
+		}
+		
 		#find SmoothingsEC
 		SmoothingsEC = findSmoothingsEC(displacement, curves, Eccon, SmoothingOneC)
 		print(c("SmoothingsEC:",SmoothingsEC))
 		
-		print("curves before reduceCurveBySpeed")
+		print("curves after reduceCurveBySpeed")
 		print(curves)
 
-		#reduceCurveBySpeed
-		for(i in 1:n) {
-			reduceTemp=reduceCurveBySpeed(Eccon, i, curves[i,1], displacement[curves[i,1]:curves[i,2]], 
-						      SmoothingsEC[i], SmoothingOneC)
-			curves[i,1] = reduceTemp[1]
-			curves[i,2] = reduceTemp[2]
-		}
 		
 		if(curvesPlot) {
 			#/10 mm -> cm
@@ -2325,7 +2330,7 @@ doProcess <- function(options) {
 		     		xlab="",ylab="",axes=F)
 			
 			if(isInertial(EncoderConfigurationName))
-				mtext("body speed ",side=4,adj=1,line=-1,col="green2")
+				mtext("body speed ",side=4,adj=1,line=-1,col="green2",cex=.8)
 			else
 				mtext("speed ",side=4,adj=1,line=-1,col="green2")
 
@@ -2508,7 +2513,8 @@ doProcess <- function(options) {
 	if(
 	   Analysis == "powerBars" || Analysis == "cross" || 
 	   Analysis == "1RMBadillo2010" || Analysis == "1RMAnyExercise" || 
-	   Analysis == "curves" || writeCurves) 
+	   Analysis == "curves" || Analysis == "neuromuscularProfile" ||
+	   writeCurves) 
 	{
 		paf = data.frame()
 		discardedCurves = NULL
@@ -2659,6 +2665,52 @@ doProcess <- function(options) {
 		else if(Analysis == "1RMBadillo2010") {
 			paint1RMBadillo2010(paf, Title, OutputData1)
 		} 
+		else if(Analysis == "neuromuscularProfile") {
+			#only signal, it's a jump, use mass of the body (100%) + mass Extra if any
+
+			if(n < 24) {
+				plot(0,0,type="n",axes=F,xlab="",ylab="")
+				text(x=0,y=0,"Not enough data.\nNeed 6 jumps and 4 phases for each jump (ecc,con,ecc,con).",cex=1.5)
+				dev.off()
+				write("", OutputData1)
+				quit()
+			}
+			npj <- neuromuscularProfileGetData(displacement, curves, (MassBody + MassExtra), SmoothingOneC)
+					    
+			np.bar.load <- mean(c(
+					      npj[[1]]$e1$rfd.avg,
+					      npj[[2]]$e1$rfd.avg,
+					      npj[[3]]$e1$rfd.avg
+					      ))
+			np.bar.explode <- mean(c(
+						 npj[[1]]$c$cl.rfd.avg,
+						 npj[[2]]$c$cl.rfd.avg,
+						 npj[[3]]$c$cl.rfd.avg
+						 ))
+			np.bar.drive <- mean(c(
+					       npj[[1]]$c$cl.i,
+					       npj[[2]]$c$cl.i,
+					       npj[[3]]$c$cl.i
+					       ))
+
+			par(mar=c(3,4,2,4))
+			par(mfrow=c(2,1))
+			neuromuscularProfilePlotBars(Title, np.bar.load, np.bar.explode, np.bar.drive)
+			
+			par(mar=c(4,4,1,4))
+			neuromuscularProfilePlotOther(
+						      displacement, #curves,
+						      list(npj[[1]]$l.context, npj[[2]]$l.context, npj[[3]]$l.context),
+						      (MassBody + MassExtra), SmoothingOneC)
+			#TODO: calcular un SmothingOneECE i passar-lo a PlotOther enlloc del SmoothingOneC
+			par(mfrow=c(1,1))
+
+
+			#don't write the curves, write npj
+			writeCurves = FALSE
+
+			neuromuscularProfileWriteData(npj, OutputData1)
+		}
 		
 		if(Analysis == "curves" || writeCurves) {
 			if(singleFile)
