@@ -191,7 +191,7 @@ public class EncoderStruct
 	~EncoderStruct() {}
 }
 
-//used on TreeView
+//used on TreeViews capture and analyze
 public class EncoderCurve
 {
 	public EncoderCurve () {
@@ -270,6 +270,117 @@ public class EncoderCurve
 	public string PP_PPT;
 }
 
+//used on TreeView
+public class EncoderNeuromuscularData
+{
+	public string n; 
+	public int e1_range;
+	public int e1_t;
+	public double e1_fmax;
+	public double e1_rfd_avg;
+	public double e1_i;
+
+	public int ca_range;
+	public int cl_t;
+	public double cl_rfd_avg;
+	public double cl_i;
+
+	public double cl_f_avg;
+	public double cl_vf;
+	public double cl_f_max;
+
+	public double cl_s_avg;
+	public double cl_s_max;
+	public double cl_p_avg;
+	public double cl_p_max;
+
+	public int e2f_t;
+	public double e2f_f_max;
+	public int e2f_f_max_t;
+	public double e2f_rfd_max;
+
+	public EncoderNeuromuscularData () {
+	}
+
+	//used on TreeView analyze
+	public EncoderNeuromuscularData (
+			string n, 
+			int e1_range, int e1_t, double e1_fmax, double e1_rfd_avg, double e1_i,
+			int ca_range, int cl_t, double cl_rfd_avg, double cl_i, 
+			double cl_f_avg, double cl_vf, double cl_f_max, 
+			double cl_s_avg, double cl_s_max, double cl_p_avg, double cl_p_max, 
+			int e2f_t, double e2f_f_max, int e2f_f_max_t, double e2f_rfd_max
+			)
+	{
+		this.n = n;
+		this.e1_range = e1_range; 
+		this.e1_t = e1_t;
+		this.e1_fmax = e1_fmax;
+		this.e1_rfd_avg = e1_rfd_avg;
+		this.e1_i = e1_i;
+		this.ca_range = ca_range;
+		this.cl_t = cl_t;
+		this.cl_rfd_avg = cl_rfd_avg;
+		this.cl_i = cl_i;
+		this.cl_f_avg = cl_f_avg;
+		this.cl_vf = cl_vf;
+		this.cl_f_max = cl_f_max;
+		this.cl_s_avg = cl_s_avg;
+		this.cl_s_max = cl_s_max;
+		this.cl_p_avg = cl_p_avg;
+		this.cl_p_max = cl_p_max;
+		this.e2f_t = e2f_t;
+		this.e2f_f_max = e2f_f_max;
+		this.e2f_f_max_t = e2f_f_max_t;
+		this.e2f_rfd_max = e2f_rfd_max;
+	}
+
+	//reading contents file from graph.R
+	public EncoderNeuromuscularData (string [] cells)
+	{
+		//cell[0] is not converted because is string
+		for(int i = 1 ; i < cells.Length ;  i ++)
+			cells[i] = Util.TrimDecimals(Convert.ToDouble(Util.ChangeDecimalSeparator(cells[i])),3);
+	
+		this.n 		= cells[0];
+		this.e1_range 	= Convert.ToInt32(cells[1]); 
+		this.e1_t 	= Convert.ToInt32(cells[2]);
+		this.e1_fmax 	= Convert.ToDouble(cells[3]);
+		this.e1_rfd_avg	= Convert.ToDouble(cells[4]);
+		this.e1_i	= Convert.ToDouble(cells[5]);
+		this.ca_range	= Convert.ToInt32(cells[6]);
+		this.cl_t 	= Convert.ToInt32(cells[7]);
+		this.cl_rfd_avg = Convert.ToDouble(cells[8]);
+		this.cl_i 	= Convert.ToDouble(cells[9]);
+		this.cl_f_avg 	= Convert.ToDouble(cells[10]);
+		this.cl_vf 	= Convert.ToDouble(cells[11]);
+		this.cl_f_max 	= Convert.ToDouble(cells[12]);
+		this.cl_s_avg 	= Convert.ToDouble(cells[13]);
+		this.cl_s_max 	= Convert.ToDouble(cells[14]);
+		this.cl_p_avg 	= Convert.ToDouble(cells[15]);
+		this.cl_p_max 	= Convert.ToDouble(cells[16]);
+		this.e2f_t 	= Convert.ToInt32(cells[17]);
+		this.e2f_f_max 	= Convert.ToDouble(cells[18]);
+		this.e2f_f_max_t = Convert.ToInt32(cells[19]);
+		this.e2f_rfd_max = Convert.ToDouble(cells[20]);
+	}
+
+	public string ToCSV() {
+		string sep = ";";
+		return 
+			n + sep + e1_range.ToString() + sep + 
+			e1_t.ToString() + sep + e1_fmax.ToString() + sep + 
+			e1_rfd_avg.ToString() + sep + e1_i.ToString() + sep + 
+			ca_range.ToString() + sep + cl_t.ToString() + sep + 
+			cl_rfd_avg.ToString() + sep + cl_i.ToString() + sep + 
+			cl_f_avg.ToString() + sep + cl_vf.ToString() + sep + cl_f_max.ToString() + sep + 
+			cl_s_avg.ToString() + sep + cl_s_max.ToString() + sep + 
+			cl_p_avg.ToString() + sep + cl_p_max.ToString() + sep + 
+			e2f_t.ToString() + sep + e2f_f_max.ToString() + sep + 
+			e2f_f_max_t.ToString() + sep + e2f_rfd_max;
+	}
+}
+
 public class EncoderSQL
 {
 	public string uniqueID;
@@ -629,7 +740,7 @@ public class EncoderConfiguration {
 		position = 0;
 		image = Constants.FileNameEncoderLinearFreeWeight;
 		code = Constants.DefaultEncoderConfigurationCode;
-		text = "Linear encoder attached to a barbell.";
+		text = "Linear encoder attached to a barbell." + "\n" + "Also tests without extra load like jumps.";
 		has_d = false;
 		has_D = false;
 		has_angle_push = false;
@@ -660,23 +771,24 @@ public class EncoderConfiguration {
 			position = 0;
 			image = Constants.FileNameEncoderLinearFreeWeight;
 			code = Constants.DefaultEncoderConfigurationCode;
-			text = "Linear encoder attached to a barbell.";
+			text = Catalog.GetString("Linear encoder attached to a barbell.") + "\n" + 
+				Catalog.GetString("Also tests without extra load like jumps.");
 		}
 		else if(name == Constants.EncoderConfigurationNames.LINEARINVERTED) {
 			type = Constants.EncoderType.LINEAR;
 			position = 1;
 			image =Constants.FileNameEncoderLinearFreeWeightInv;
 			code = "Linear inv - barbell";
-			text = "Linear encoder inverted attached to a barbell.";
+			text = Catalog.GetString("Linear encoder inverted attached to a barbell.");
 		}
 		else if(name == Constants.EncoderConfigurationNames.LINEARINERTIAL) {
 			type = Constants.EncoderType.LINEAR;
 			position = 2;
 			image = Constants.FileNameEncoderLinearInertial;
 			code = "Linear - inertial machine";
-			text = "Linear encoder on inertia machine." + "\n" + 
-				"Configuration NOT Recommended! Please use a rotary encoder" + "\n" +
-				"Person has to start fully extended (on the toes).";
+			text = Catalog.GetString("Linear encoder on inertia machine.") + "\n" + 
+				Catalog.GetString("Configuration NOT Recommended! Please use a rotary encoder.") + "\n" +
+				Catalog.GetString("Person has to start fully extended (on the toes).");
 			
 			has_d = true;
 			has_inertia = true;
@@ -686,9 +798,9 @@ public class EncoderConfiguration {
 			position = 3;
 			image = Constants.FileNameEncoderWeightedMovPulleyOnPerson1;
 			code = "Linear - barbell - moving pulley";
-			text = "Linear encoder attached to a barbell." + " " + 
-				"Barbell is connected to a weighted moving pulley." 
-				+ " " + "Mass is geared down by 2."; 
+			text = Catalog.GetString("Linear encoder attached to a barbell.") + " " + 
+				Catalog.GetString("Barbell is connected to a weighted moving pulley.") 
+				+ " " + Catalog.GetString("Mass is geared down by 2."); 
 		
 			gearedDown = 2;
 		}
@@ -697,9 +809,9 @@ public class EncoderConfiguration {
 			position = 4;
 			image = Constants.FileNameEncoderWeightedMovPulleyOnPerson1Inv;
 			code = "Linear inv - barbell - moving pulley";
-			text = "Linear encoder inverted attached to a barbell." + " " + 
-				"Barbell is connected to a weighted moving pulley."
-				+ " " + "Mass is geared down by 2."; 
+			text = Catalog.GetString("Linear encoder inverted attached to a barbell.") + " " + 
+				Catalog.GetString("Barbell is connected to a weighted moving pulley.")
+				+ " " + Catalog.GetString("Mass is geared down by 2."); 
 		
 			gearedDown = 2;
 		}
@@ -708,9 +820,9 @@ public class EncoderConfiguration {
 			position = 5;
 			image = Constants.FileNameEncoderWeightedMovPulleyOnPerson2;
 			code = "Linear - barbell - pulley - moving pulley";
-			text = "Linear encoder attached to a barbell." + " " + 
-				"Barbell is connected to a fixed pulley that is connected to a weighted moving pulley."
-				+ " " + "Mass is geared down by 2."; 
+			text = Catalog.GetString("Linear encoder attached to a barbell.") + " " + 
+				Catalog.GetString("Barbell is connected to a fixed pulley that is connected to a weighted moving pulley.")
+				+ " " + Catalog.GetString("Mass is geared down by 2."); 
 		
 			gearedDown = 2;
 		}
@@ -719,9 +831,9 @@ public class EncoderConfiguration {
 			position = 6;
 			image = Constants.FileNameEncoderWeightedMovPulleyOnPerson2Inv;
 			code = "Linear inv - barbell - pulley - moving pulley";
-			text = "Linear encoder inverted attached to a barbell." + " " + 
-				"Barbell is connected to a fixed pulley that is connected to a weighted moving pulley."
-				+ " " + "Mass is geared down by 2."; 
+			text = Catalog.GetString("Linear encoder inverted attached to a barbell.") + " " + 
+				Catalog.GetString("Barbell is connected to a fixed pulley that is connected to a weighted moving pulley.")
+				+ " " + Catalog.GetString("Mass is geared down by 2."); 
 		
 			gearedDown = 2;
 		}
@@ -730,8 +842,8 @@ public class EncoderConfiguration {
 			position = 7;
 			image = Constants.FileNameEncoderWeightedMovPulleyOnLinearEncoder;
 			code = "Linear - moving pulley";
-			text = "Linear encoder attached to a weighted moving pulley."
-				+ " " + "Mass is geared down by 2."; 
+			text = Catalog.GetString("Linear encoder attached to a weighted moving pulley.")
+				+ " " + Catalog.GetString("Mass is geared down by 2."); 
 		
 			gearedDown = 2;
 		}
@@ -740,7 +852,7 @@ public class EncoderConfiguration {
 			position = 8;
 			image = Constants.FileNameEncoderLinearOnPlane;
 			code = "Linear - inclinated plane";
-			text = "Linear encoder on a inclinated plane.";
+			text = Catalog.GetString("Linear encoder on a inclinated plane.");
 			
 			has_angle_push = true;
 			has_angle_weight = false;
@@ -750,7 +862,7 @@ public class EncoderConfiguration {
 			position = 9;
 			image = Constants.FileNameEncoderLinearOnPlaneWeightDiffAngle;
 			code = "Linear - inclinated plane different angle";
-			text = "Linear encoder on a inclinated plane moving a weight in different angle.";
+			text = Catalog.GetString("Linear encoder on a inclinated plane moving a weight in different angle.");
 			
 			has_angle_push = true;
 			has_angle_weight = true;
@@ -760,14 +872,14 @@ public class EncoderConfiguration {
 			position = 0;
 			image = Constants.FileNameEncoderFrictionSide;
 			code = "Rotary friction - pulley";
-			text = "Rotary friction encoder on pulley.";
+			text = Catalog.GetString("Rotary friction encoder on pulley.");
 		}
 		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONAXIS) {
 			type = Constants.EncoderType.ROTARYFRICTION;
 			position = 1;
 			image = Constants.FileNameEncoderFrictionAxis;
 			code = "Rotary friction - pulley axis";
-			text = "Rotary friction encoder on pulley axis.";
+			text = Catalog.GetString("Rotary friction encoder on pulley axis.");
 
 			has_d = true;
 			has_D = true;
@@ -777,9 +889,10 @@ public class EncoderConfiguration {
 			position = 2;
 			image = Constants.FileNameEncoderFrictionSideInertial;
 			code = "Rotary friction - inertial machine side";
-			text = "Rotary friction encoder on inertial machine side." + "\n" +
-				"Person has to start fully extended (on the toes).";
+			text = Catalog.GetString("Rotary friction encoder on inertial machine side.") + "\n" +
+				Catalog.GetString("Person has to start fully extended (on the toes).");
 
+			has_d = true;
 			has_D = true;
 			has_inertia = true;
 		}
@@ -788,8 +901,8 @@ public class EncoderConfiguration {
 			position = 3;
 			image = Constants.FileNameEncoderFrictionAxisInertial;
 			code = "Rotary friction axis - inertial machine axis";
-			text = "Rotary friction encoder on inertial machine axis." + "\n" +
-				"Person has to start fully extended (on the toes).";
+			text = Catalog.GetString("Rotary friction encoder on inertial machine axis.") + "\n" +
+				Catalog.GetString("Person has to start fully extended (on the toes).");
 
 			has_d = true;
 			has_inertia = true;
@@ -799,14 +912,14 @@ public class EncoderConfiguration {
 			position = 4;
 			image = Constants.FileNameEncoderFrictionWithMovPulley;
 			code = "Rotary friction - moving pulley";
-			text = "Rotary friction encoder on weighted moving pulley.";
+			text = Catalog.GetString("Rotary friction encoder on weighted moving pulley.");
 		}
 		else if(name == Constants.EncoderConfigurationNames.ROTARYAXIS) {
 			type = Constants.EncoderType.ROTARYAXIS;
 			position = 0;
 			image = Constants.FileNameEncoderRotaryAxisOnAxis;
 			code = "Rotary axis - pulley axis";
-			text = "Rotary axis encoder on pulley axis.";
+			text = Catalog.GetString("Rotary axis encoder on pulley axis.");
 
 			has_D = true;
 		}
@@ -815,8 +928,8 @@ public class EncoderConfiguration {
 			position = 1;
 			image = Constants.FileNameEncoderAxisInertial;
 			code = "Rotary axis - inertial machine";
-			text = "Rotary axis encoder on inertial machine." + "\n" +
-				"Person has to start fully extended (on the toes).";
+			text = Catalog.GetString("Rotary axis encoder on inertial machine.") + "\n" +
+			Catalog.GetString("Person has to start fully extended (on the toes).");
 
 			has_d = true;
 			has_inertia = true;
@@ -826,8 +939,8 @@ public class EncoderConfiguration {
 			position = 2;
 			image = Constants.FileNameEncoderAxisWithMovPulley;
 			code = "Rotary axis - moving pulley";
-			text = "Rotary axis encoder on weighted moving pulley."
-				+ " " + "Mass is geared down by 2."; 
+			text = Catalog.GetString("Rotary axis encoder on weighted moving pulley.")
+				+ " " + Catalog.GetString("Mass is geared down by 2."); 
 			
 			gearedDown = 2;
 		}
