@@ -157,6 +157,7 @@ public partial class ChronoJumpWindow
 	Gdk.Pixmap event_execute_pixmap = null;
 	
 
+	string event_execute_label_simulated;
 	int event_execute_personID;	
 	//int sessionID;
 	//string event_execute_personName;	
@@ -187,6 +188,7 @@ public partial class ChronoJumpWindow
 	
 	//for writing text
 	Pango.Layout layout;
+	Pango.Layout layoutBig;
 
 	static EventGraphConfigureWindow eventGraphConfigureWin;
 	
@@ -196,6 +198,7 @@ public partial class ChronoJumpWindow
 	
 
 	ExecutingGraphData event_execute_initializeVariables (
+			bool simulated,
 			int personID,
 			string personName,
 			string phasesName, 
@@ -213,6 +216,10 @@ public partial class ChronoJumpWindow
 
 		event_execute_configureColors();
 	
+		event_execute_label_simulated = "";
+		if(simulated) 
+			event_execute_label_simulated = Catalog.GetString("Simulated");
+
 		event_graph_label_graph_person.Text = personName;
 		event_graph_label_graph_test.Text = event_execute_eventType;
 				
@@ -263,13 +270,18 @@ public partial class ChronoJumpWindow
 		
 		layout = new Pango.Layout (event_execute_drawingarea.PangoContext);
 		layout.FontDescription = Pango.FontDescription.FromString ("Courier 7");
+
+		layoutBig = new Pango.Layout (event_execute_drawingarea.PangoContext);
+		layoutBig.FontDescription = Pango.FontDescription.FromString ("Courier 14");
+		//layoutBig.Alignment = Pango.Alignment.Center; //doesn't work, see GetPixelSize below
 	
 		eventHasEnded = false;
 
 		checkbutton_video.Sensitive = false;
 		if(videoOn) {
 			capturer.ClickRec();
-			label_video_feedback.Text = Catalog.GetString("Recording");
+			//label_video_feedback.Text = Catalog.GetString("Recording");
+			label_video_feedback.Text = "Rec.";
 		}
 
 		ExecutingGraphData executingGraphData = new ExecutingGraphData(
@@ -539,7 +551,7 @@ public partial class ChronoJumpWindow
 	
 
 	// simple and DJ jump	
-	public void PrepareJumpSimpleGraph(double tv, double tc) 
+	public void PrepareJumpSimpleGraph(PrepareEventGraphJumpSimple eventGraph)
 	{
 		//check graph properties window is not null (propably user has closed it with the DeleteEvent
 		//then create it, but not show it
@@ -547,26 +559,6 @@ public partial class ChronoJumpWindow
 			eventGraphConfigureWin = EventGraphConfigureWindow.Show(false);
 
 		
-		//obtain data
-		string []jumps = SqliteJump.SelectJumps(
-				currentSession.UniqueID, event_execute_personID, "", event_execute_eventType);
-
-		double tvPersonAVG = SqliteSession.SelectAVGEventsOfAType(
-				currentSession.UniqueID, event_execute_personID, 
-				event_execute_tableName, event_execute_eventType, "TV");
-		double tvSessionAVG = SqliteSession.SelectAVGEventsOfAType(
-				currentSession.UniqueID, -1, event_execute_tableName, event_execute_eventType, "TV");
-
-		double tcPersonAVG = 0; 
-		double tcSessionAVG = 0; 
-		if(tc > 0) {
-			tcPersonAVG = SqliteSession.SelectAVGEventsOfAType(
-					currentSession.UniqueID, event_execute_personID, 
-					event_execute_tableName, event_execute_eventType, "TC");
-			tcSessionAVG = SqliteSession.SelectAVGEventsOfAType(
-					currentSession.UniqueID, -1, event_execute_tableName, event_execute_eventType, "TC");
-		}
-		
 		double maxValue = 0;
 		double minValue = 0;
 		int topMargin = 10; 
@@ -575,9 +567,11 @@ public partial class ChronoJumpWindow
 		//if max value of graph is automatic
 		if(eventGraphConfigureWin.Max == -1) {
 			maxValue = Util.GetMax(
-					tv.ToString() + "=" + tvPersonAVG.ToString() + "=" + tvSessionAVG.ToString() + "=" +
-					tc.ToString() + "=" + tcPersonAVG.ToString() + "=" + tcSessionAVG.ToString());
-			foreach(string myStr in jumps) {
+					eventGraph.tv.ToString() + "=" + 
+					eventGraph.tvPersonAVGAtSQL.ToString() + "=" + eventGraph.tvSessionAVGAtSQL.ToString() + "=" +
+					eventGraph.tc.ToString() + "=" + 
+					eventGraph.tcPersonAVGAtSQL.ToString() + "=" + eventGraph.tcSessionAVGAtSQL.ToString());
+			foreach(string myStr in eventGraph.jumpsAtSQL) {
 				string [] jump = myStr.Split(new char[] {':'});
 				if(Convert.ToDouble(jump[5]) > maxValue)
 					maxValue = Convert.ToDouble(jump[5]); //tf
@@ -591,11 +585,13 @@ public partial class ChronoJumpWindow
 		
 		//if min value of graph is automatic
 		if(eventGraphConfigureWin.Min == -1) {
-			string myString = tv.ToString() + "=" + tvPersonAVG.ToString() + "=" + tvSessionAVG.ToString();
-			if(tc > 0)
-				myString = myString + "=" + tc.ToString() + "=" + tcPersonAVG.ToString() + "=" + tcSessionAVG.ToString();
+			string myString = eventGraph.tv.ToString() + "=" + 
+				eventGraph.tvPersonAVGAtSQL.ToString() + "=" + eventGraph.tvSessionAVGAtSQL.ToString();
+			if(eventGraph.tc > 0)
+				myString = myString + "=" + eventGraph.tc.ToString() + "=" + 
+					eventGraph.tcPersonAVGAtSQL.ToString() + "=" + eventGraph.tcSessionAVGAtSQL.ToString();
 			minValue = Util.GetMin(myString);
-			foreach(string myStr in jumps) {
+			foreach(string myStr in eventGraph.jumpsAtSQL) {
 				string [] jump = myStr.Split(new char[] {':'});
 				if(Convert.ToDouble(jump[5]) < minValue)
 					minValue = Convert.ToDouble(jump[5]); //tf
@@ -608,11 +604,16 @@ public partial class ChronoJumpWindow
 		}
 		
 		//paint graph
-		paintJumpSimple (event_execute_drawingarea, jumps, tv, tvPersonAVG, tvSessionAVG, 
-				tc, tcPersonAVG, tcSessionAVG, maxValue, minValue, topMargin, bottomMargin);
+		paintJumpSimple (event_execute_drawingarea, eventGraph.jumpsAtSQL, 
+				eventGraph.tv, eventGraph.tvPersonAVGAtSQL, eventGraph.tvSessionAVGAtSQL, 
+				eventGraph.tc, eventGraph.tcPersonAVGAtSQL, eventGraph.tcSessionAVGAtSQL,
+			       	maxValue, minValue, topMargin, bottomMargin);
 
 		//printLabels
-		printLabelsJumpSimple (tv, tvPersonAVG, tvSessionAVG, tc, tcPersonAVG, tcSessionAVG);
+		printLabelsJumpSimple (
+				eventGraph.tv, eventGraph.tvPersonAVGAtSQL, eventGraph.tvSessionAVGAtSQL, 
+				eventGraph.heightPersonAVGAtSQL, eventGraph.heightSessionAVGAtSQL, 
+				eventGraph.tc, eventGraph.tcPersonAVGAtSQL, eventGraph.tcSessionAVGAtSQL);
 		
 		// -- refresh
 		event_execute_drawingarea.QueueDraw();
@@ -700,7 +701,7 @@ Log.WriteLine("Preparing reactive A");
 			
 
 	// run simple
-	public void PrepareRunSimpleGraph(double time, double speed) 
+	public void PrepareRunSimpleGraph(PrepareEventGraphRunSimple eventGraph)
 	{
 		//check graph properties window is not null (propably user has closed it with the DeleteEvent
 		//then create it, but not show it
@@ -712,21 +713,6 @@ Log.WriteLine("Preparing reactive A");
 		if(eventGraphConfigureWin.RunsTimeActive) 
 			paintTime = true;
 		
-		//obtain data
-		string [] runs = SqliteRun.SelectRuns(currentSession.UniqueID, event_execute_personID, event_execute_eventType);
-
-		double timePersonAVG = SqliteSession.SelectAVGEventsOfAType(currentSession.UniqueID, event_execute_personID, event_execute_tableName, event_execute_eventType, "time");
-		double timeSessionAVG = SqliteSession.SelectAVGEventsOfAType(currentSession.UniqueID, -1, event_execute_tableName, event_execute_eventType, "time");
-
-		//double distancePersonAVG = SqliteSession.SelectAVGEventsOfAType(currentSession.UniqueID, event_execute_personID, event_execute_tableName, event_execute_eventType, "distance");
-		//double distanceSessionAVG = SqliteSession.SelectAVGEventsOfAType(currentSession.UniqueID, -1, event_execute_tableName, event_execute_eventType, "distance");
-		//better to know speed like:
-		//SELECT AVG(distance/time) from run; than 
-		//SELECT AVG(distance) / SELECT AVG(time) 
-		//first is ok, because is the speed AVG
-		//2nd is not good because it tries to do an AVG of all distances and times
-		double speedPersonAVG = SqliteSession.SelectAVGEventsOfAType(currentSession.UniqueID, event_execute_personID, event_execute_tableName, event_execute_eventType, "distance/time");
-		double speedSessionAVG = SqliteSession.SelectAVGEventsOfAType(currentSession.UniqueID, -1, event_execute_tableName, event_execute_eventType, "distance/time");
 
 		double maxValue = 0;
 		double minValue = 0;
@@ -736,16 +722,18 @@ Log.WriteLine("Preparing reactive A");
 		//if max value of graph is automatic
 		if(eventGraphConfigureWin.Max == -1) {
 			if(paintTime) {
-				maxValue = Util.GetMax(time.ToString() + "=" + timePersonAVG.ToString() + "=" + timeSessionAVG.ToString());
-				foreach(string myStr in runs) {
+				maxValue = Util.GetMax(eventGraph.time.ToString() + "=" + 
+						eventGraph.timePersonAVGAtSQL.ToString() + "=" + eventGraph.timeSessionAVGAtSQL.ToString());
+				foreach(string myStr in eventGraph.runsAtSQL) {
 					string [] run = myStr.Split(new char[] {':'});
 					if(Convert.ToDouble(run[6]) > maxValue)
 						maxValue = Convert.ToDouble(run[6]); 
 				}
 			}
 			else {						//paint speed
-				maxValue = Util.GetMax(speed.ToString() + "=" + speedPersonAVG.ToString() + "=" + speedSessionAVG.ToString());
-				foreach(string myStr in runs) {
+				maxValue = Util.GetMax(eventGraph.speed.ToString() + "=" + 
+						eventGraph.speedPersonAVGAtSQL.ToString() + "=" + eventGraph.speedSessionAVGAtSQL.ToString());
+				foreach(string myStr in eventGraph.runsAtSQL) {
 					string [] run = myStr.Split(new char[] {':'});
 					double mySpeed = Convert.ToDouble(Util.GetSpeed(run[5], run[6], true));
 					if(mySpeed > maxValue)
@@ -760,16 +748,18 @@ Log.WriteLine("Preparing reactive A");
 		//if min value of graph is automatic
 		if(eventGraphConfigureWin.Min == -1) {
 			if(paintTime) {
-				minValue = Util.GetMin(time.ToString() + "=" + timePersonAVG.ToString() + "=" + timeSessionAVG.ToString());
-				foreach(string myStr in runs) {
+				minValue = Util.GetMin(eventGraph.time.ToString() + "=" + 
+						eventGraph.timePersonAVGAtSQL.ToString() + "=" + eventGraph.timeSessionAVGAtSQL.ToString());
+				foreach(string myStr in eventGraph.runsAtSQL) {
 					string [] run = myStr.Split(new char[] {':'});
 					if(Convert.ToDouble(run[6]) < minValue)
 						minValue = Convert.ToDouble(run[6]); 
 				}
 			}
 			else {
-				minValue = Util.GetMin(speed.ToString() + "=" + speedPersonAVG.ToString() + "=" + speedSessionAVG.ToString());
-				foreach(string myStr in runs) {
+				minValue = Util.GetMin(eventGraph.speed.ToString() + "=" + 
+						eventGraph.speedPersonAVGAtSQL.ToString() + "=" + eventGraph.speedSessionAVGAtSQL.ToString());
+				foreach(string myStr in eventGraph.runsAtSQL) {
 					string [] run = myStr.Split(new char[] {':'});
 					double mySpeed = Convert.ToDouble(Util.GetSpeed(run[5], run[6], true));
 					if(mySpeed < minValue)
@@ -784,12 +774,17 @@ Log.WriteLine("Preparing reactive A");
 		
 		//paint graph
 		if(paintTime)
-			paintRunSimple (event_execute_drawingarea, pen_rojo, runs, time, timePersonAVG, timeSessionAVG, maxValue, minValue, topMargin, bottomMargin);
+			paintRunSimple (event_execute_drawingarea, pen_rojo, eventGraph.runsAtSQL, 
+					eventGraph.time, eventGraph.timePersonAVGAtSQL, eventGraph.timeSessionAVGAtSQL, 
+					maxValue, minValue, topMargin, bottomMargin);
 		else						//paint speed
-			paintRunSimple (event_execute_drawingarea, pen_azul_claro, runs, speed, speedPersonAVG, speedSessionAVG, maxValue, minValue, topMargin, bottomMargin);
+			paintRunSimple (event_execute_drawingarea, pen_azul_claro, eventGraph.runsAtSQL, 
+					eventGraph.speed, eventGraph.speedPersonAVGAtSQL, eventGraph.speedSessionAVGAtSQL, 
+					maxValue, minValue, topMargin, bottomMargin);
 		
 		//printLabels
-		printLabelsRunSimple (time, timePersonAVG, timeSessionAVG, speed, speedPersonAVG, speedSessionAVG);
+		printLabelsRunSimple (eventGraph.time, eventGraph.timePersonAVGAtSQL, eventGraph.timeSessionAVGAtSQL, 
+				eventGraph.speed, eventGraph.speedPersonAVGAtSQL, eventGraph.speedSessionAVGAtSQL);
 		
 		// -- refresh
 		event_execute_drawingarea.QueueDraw();
@@ -897,21 +892,13 @@ Log.WriteLine("Preparing reactive A");
 		event_execute_drawingarea.QueueDraw();
 	}
 	
-	public void PrepareReactionTimeGraph(double time) 
+	public void PrepareReactionTimeGraph(PrepareEventGraphReactionTime eventGraph) 
 	{
 		//check graph properties window is not null (propably user has closed it with the DeleteEvent
 		//then create it, but not show it
 		if(eventGraphConfigureWin == null)
 			eventGraphConfigureWin = EventGraphConfigureWindow.Show(false);
 
-		
-		//obtain data
-		string [] rts = SqliteReactionTime.SelectReactionTimes(currentSession.UniqueID, event_execute_personID);
-
-		double timePersonAVG = SqliteSession.SelectAVGEventsOfAType(
-				currentSession.UniqueID, event_execute_personID, event_execute_tableName, event_execute_eventType, "time");
-		double timeSessionAVG = SqliteSession.SelectAVGEventsOfAType(
-				currentSession.UniqueID, -1, event_execute_tableName, event_execute_eventType, "time");
 
 		double maxValue = 0;
 		double minValue = 0;
@@ -921,7 +908,14 @@ Log.WriteLine("Preparing reactive A");
 		//if max value of graph is automatic
 		if(eventGraphConfigureWin.Max == -1) {
 			maxValue = Util.GetMax(
-					time.ToString() + "=" + timePersonAVG.ToString() + "=" + timeSessionAVG.ToString());
+					eventGraph.time.ToString() + "=" + 
+					eventGraph.timePersonAVGAtSQL.ToString() + "=" + eventGraph.timeSessionAVGAtSQL.ToString());
+
+			foreach(string myStr in eventGraph.rtsAtSQL) {
+				string [] rts = myStr.Split(new char[] {':'});
+				if(Convert.ToDouble(rts[5]) > maxValue)
+					maxValue = Convert.ToDouble(rts[5]); 
+			}
 		} else {
 			maxValue = eventGraphConfigureWin.Max;
 			topMargin = 0;
@@ -930,16 +924,19 @@ Log.WriteLine("Preparing reactive A");
 		//if min value of graph is automatic
 		if(eventGraphConfigureWin.Min == -1) {
 			minValue = Util.GetMin(
-					time.ToString() + "=" + timePersonAVG.ToString() + "=" + timeSessionAVG.ToString());
+					eventGraph.time.ToString() + "=" + 
+					eventGraph.timePersonAVGAtSQL.ToString() + "=" + eventGraph.timeSessionAVGAtSQL.ToString());
 		} else {
 			minValue = eventGraphConfigureWin.Min;
 			bottomMargin = 0;
 		}
 		
 		//paint graph (use simple jump method)
-		paintJumpSimple (event_execute_drawingarea, rts, time, timePersonAVG, timeSessionAVG, 0, 0, 0, maxValue, minValue, topMargin, bottomMargin);
+		paintJumpSimple (event_execute_drawingarea, eventGraph.rtsAtSQL, 
+				eventGraph.time, eventGraph.timePersonAVGAtSQL, eventGraph.timeSessionAVGAtSQL, 
+				0, 0, 0, maxValue, minValue, topMargin, bottomMargin);
 
-		printLabelsReactionTime (time, timePersonAVG, timeSessionAVG);
+		printLabelsReactionTime (eventGraph.time, eventGraph.timePersonAVGAtSQL, eventGraph.timeSessionAVGAtSQL);
 		
 		// -- refresh
 		event_execute_drawingarea.QueueDraw();
@@ -999,7 +996,11 @@ Log.WriteLine("Preparing reactive A");
 	}
 	
 
-	private void printLabelsJumpSimple (double tvNow, double tvPerson, double tvSession, double tcNow, double tcPerson, double tcSession) {
+	private void printLabelsJumpSimple (
+			double tvNow, double tvPerson, double tvSession, 
+			double heightPerson, double heightSession,
+			double tcNow, double tcPerson, double tcSession) 
+	{
 		if(tcNow > 0) {
 			event_execute_label_jump_simple_tc_now.Text = Util.TrimDecimals(tcNow.ToString(), prefsDigitsNumber);
 			event_execute_label_jump_simple_tc_person.Text = Util.TrimDecimals(tcPerson.ToString(), prefsDigitsNumber);
@@ -1013,12 +1014,12 @@ Log.WriteLine("Preparing reactive A");
 		event_execute_label_jump_simple_tf_person.Text = Util.TrimDecimals(tvPerson.ToString(), prefsDigitsNumber);
 		event_execute_label_jump_simple_tf_session.Text = Util.TrimDecimals(tvSession.ToString(), prefsDigitsNumber);
 		
+		//current height is calculated from tvNow
+		//heightPerson and heightSession is calculated for every jump, then done the AVG, then send here
 		event_execute_label_jump_simple_height_now.Text = Util.TrimDecimals(
 				Util.GetHeightInCentimeters(tvNow.ToString()) , prefsDigitsNumber);
-		event_execute_label_jump_simple_height_person.Text = Util.TrimDecimals(
-				Util.GetHeightInCentimeters(tvPerson.ToString()) , prefsDigitsNumber);
-		event_execute_label_jump_simple_height_session.Text = Util.TrimDecimals(
-				Util.GetHeightInCentimeters(tvSession.ToString()) , prefsDigitsNumber);
+		event_execute_label_jump_simple_height_person.Text = Util.TrimDecimals(heightPerson.ToString(), prefsDigitsNumber);
+		event_execute_label_jump_simple_height_session.Text = Util.TrimDecimals(heightSession.ToString(), prefsDigitsNumber);
 	}
 	
 	private void printLabelsRunSimple (double timeNow, double timePerson, double timeSession, double speedNow, double speedPerson, double speedSession) {
@@ -1037,6 +1038,32 @@ Log.WriteLine("Preparing reactive A");
 		event_execute_label_reaction_time_session.Text = Util.TrimDecimals(timeSession.ToString(), prefsDigitsNumber);
 	}
 	
+	//used on simple tests
+	private void plotSimulatedMessageIfNeededAtLast(int x, int alto) {
+		if(event_execute_label_simulated != "") {
+			layoutBig.SetMarkup(event_execute_label_simulated);
+			int lWidth = 1;
+			int lHeight = 1;
+			layoutBig.GetPixelSize(out lWidth, out lHeight); 
+			event_execute_pixmap.DrawLayout (pen_negro, 
+					Convert.ToInt32(x - lWidth/2), 
+					Convert.ToInt32(alto/2 - lHeight/2), 
+					layoutBig);
+		}
+	}
+	//used on jumps reactive, runs interval
+	private void plotSimulatedMessageIfNeededAtCenter(int ancho, int alto) {
+		if(event_execute_label_simulated != "") {
+			layoutBig.SetMarkup(event_execute_label_simulated);
+			int lWidth = 1;
+			int lHeight = 1;
+			layoutBig.GetPixelSize(out lWidth, out lHeight); 
+			event_execute_pixmap.DrawLayout (pen_negro, 
+					Convert.ToInt32(ancho/2 - lWidth/2), 
+					Convert.ToInt32(alto/2 - lHeight/2), 
+					layoutBig);
+		}
+	}
 
 	private void paintJumpSimple (Gtk.DrawingArea drawingarea, string [] jumps, 
 			double tvNow, double tvPerson, double tvSession, 
@@ -1045,6 +1072,7 @@ Log.WriteLine("Preparing reactive A");
 	{
 		int ancho=drawingarea.Allocation.Width;
 		int alto=drawingarea.Allocation.Height;
+		int count;
 		
 		UtilGtk.ErasePaint(event_execute_drawingarea, event_execute_pixmap);
 		writeMarginsText(maxValue, minValue, alto);
@@ -1071,8 +1099,8 @@ Log.WriteLine("Preparing reactive A");
 			}
 
 			//red for TC
+			count = 0;
 			if(tcNow > 0) {
-				int count = 0;
 				foreach(string myStr in jumps) {
 					string [] jump = myStr.Split(new char[] {':'});
 					Rectangle rect = new Rectangle(
@@ -1089,8 +1117,8 @@ Log.WriteLine("Preparing reactive A");
 		
 			//blue for TF
 			//check it's not a take off
+			count = 0;
 			if(tvNow > 0) {
-				int count = 0;
 				foreach(string myStr in jumps) {
 					string [] jump = myStr.Split(new char[] {':'});
 					//jump[5] is ok fo jump.tv and for reactionTime.time
@@ -1111,6 +1139,11 @@ Log.WriteLine("Preparing reactive A");
 						Convert.ToInt32((ancho-event_execute_rightMargin)*(count-.5)/jumps.Length)-barDesplLeft + tctfSep, 
 						0, layout);
 			}
+
+			plotSimulatedMessageIfNeededAtLast(
+					Convert.ToInt32((ancho-event_execute_rightMargin)*(count-.5)/jumps.Length)-barDesplLeft + tctfSep 
+					+ barWidth/2,
+				       	alto);
 			
 			//paint reference guide black and green if needed
 			drawGuideOrAVG(pen_negro_discont, eventGraphConfigureWin.BlackGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
@@ -1124,6 +1157,7 @@ Log.WriteLine("Preparing reactive A");
 	{
 		int ancho=drawingarea.Allocation.Width;
 		int alto=drawingarea.Allocation.Height;
+		int count;
 		
 		UtilGtk.ErasePaint(event_execute_drawingarea, event_execute_pixmap);
 		writeMarginsText(maxValue, minValue, alto);
@@ -1141,12 +1175,12 @@ Log.WriteLine("Preparing reactive A");
 			drawGuideOrAVG(pen_green_discont, eventGraphConfigureWin.GreenGuide, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
 
 			//blue for TF
+			count = 0;
 			if(now > 0) {
 				//blue tf average discountinuos line	
 				drawGuideOrAVG(pen_azul_claro, 	person, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
 				drawGuideOrAVG(pen_azul_claro_discont, session, alto, ancho, topMargin, bottomMargin, maxValue, minValue);
 		
-				int count = 0;
 				foreach(string myStr in runs) {
 					string [] run = myStr.Split(new char[] {':'});
 					Rectangle rect = new Rectangle(
@@ -1167,6 +1201,11 @@ Log.WriteLine("Preparing reactive A");
 						Convert.ToInt32((ancho-event_execute_rightMargin)*(count-.5)/runs.Length)-barDesplLeft, 
 						0, layout);
 			}
+			
+			plotSimulatedMessageIfNeededAtLast(
+					Convert.ToInt32((ancho-event_execute_rightMargin)*(count-.5)/runs.Length)-barDesplLeft 
+					+ barWidth/2,
+				       	alto);
 		}
 	}
 
@@ -1259,6 +1298,9 @@ Log.WriteLine("Preparing reactive A");
 					Convert.ToInt32((ancho-event_execute_rightMargin)*(posMin+.5)/jumps), calculatePaintHeight(Convert.ToDouble(myTVStringFull[posMin]), alto, maxValue, minValue, topMargin, bottomMargin),
 					Convert.ToInt32((ancho-event_execute_rightMargin)*(posMin+.5)/jumps), calculatePaintHeight(Convert.ToDouble(myTCStringFull[posMin]), alto, maxValue, minValue, topMargin, bottomMargin));
 
+			
+			plotSimulatedMessageIfNeededAtCenter(ancho, alto);
+			
 			//bells & images
 			event_execute_image_jump_reactive_tf_good.Hide();
 			event_execute_image_jump_reactive_tf_bad.Hide();
@@ -1437,6 +1479,8 @@ Log.WriteLine("Preparing reactive A");
 				Util.PlaySound(Constants.SoundTypes.BAD, volumeOn);
 				event_execute_image_run_interval_time_bad.Show();
 			}
+			
+			plotSimulatedMessageIfNeededAtCenter(ancho, alto);
 		}
 		
 		event_execute_label_run_interval_time_now.Text = Util.TrimDecimals(lastTime.ToString(), prefsDigitsNumber);
@@ -1493,7 +1537,8 @@ Log.WriteLine("Preparing reactive A");
 			}
 		
 			drawCircleAndWriteValue(pen_azul, myTimeDouble, --count, pulses, ancho, alto, maxValue, minValue, topMargin, bottomMargin);
-
+			
+			plotSimulatedMessageIfNeededAtCenter(ancho, alto);
 		}
 		
 		event_execute_label_pulse_now.Text = Util.TrimDecimals(lastTime.ToString(), prefsDigitsNumber);
@@ -1764,11 +1809,9 @@ Log.WriteLine("Preparing reactive A");
 	private void on_event_execute_update_graph_in_progress_clicked(object o, EventArgs args) {
 		switch (currentEventType.Type) {
 			case EventType.Types.JUMP:
-				if(thisJumpIsSimple) {
-					PrepareJumpSimpleGraph(
-							currentEventExecute.PrepareEventGraphJumpSimpleObject.tv, 
-							currentEventExecute.PrepareEventGraphJumpSimpleObject.tc);
-				} else {
+				if(thisJumpIsSimple) 
+					PrepareJumpSimpleGraph(currentEventExecute.PrepareEventGraphJumpSimpleObject);
+				else {
 					PrepareJumpReactiveGraph(
 							currentEventExecute.PrepareEventGraphJumpReactiveObject.lastTv, 
 							currentEventExecute.PrepareEventGraphJumpReactiveObject.lastTc,
@@ -1778,11 +1821,9 @@ Log.WriteLine("Preparing reactive A");
 				}
 				break;
 			case EventType.Types.RUN:
-				if(thisRunIsSimple) {
-					PrepareRunSimpleGraph(
-							currentEventExecute.PrepareEventGraphRunSimpleObject.time,
-							currentEventExecute.PrepareEventGraphRunSimpleObject.speed);
-				} else {
+				if(thisRunIsSimple)
+					PrepareRunSimpleGraph(currentEventExecute.PrepareEventGraphRunSimpleObject);
+				else {
 					bool volumeOnHere = true;
 					//do not play good or bad sounds at RSA because we need to hear the GO sound
 					if(currentRunIntervalType.IsRSA)
@@ -1798,8 +1839,7 @@ Log.WriteLine("Preparing reactive A");
 				}
 				break;
 			case EventType.Types.REACTIONTIME:
-					PrepareReactionTimeGraph(
-							currentEventExecute.PrepareEventGraphReactionTimeObject.time);
+					PrepareReactionTimeGraph(currentEventExecute.PrepareEventGraphReactionTimeObject);
 				break;
 			case EventType.Types.PULSE:
 					PreparePulseGraph(
