@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -1160,7 +1160,7 @@ public class PersonAddModifyWindow
 			//PersonAddModifyWindowBox.button_cancel.Hide();
 		
 		PersonAddModifyWindowBox.person_win.Show ();
-		
+
 		PersonAddModifyWindowBox.fillDialog ();
 		
 		return PersonAddModifyWindowBox;
@@ -1272,6 +1272,9 @@ public class PersonAddModifyWindow
 		UtilGtk.ComboUpdate(combo_countries, myCountries, "");
 		combo_countries.Active = UtilGtk.ComboMakeActive(myCountries, 
 				Catalog.GetString(Constants.CountryUndefined));
+		
+		//create countriesTranslated, only with translated stuff
+		countriesTranslated = new String[1];
 
 		
 		combo_countries.Changed += new EventHandler (on_combo_countries_changed);
@@ -1309,11 +1312,14 @@ public class PersonAddModifyWindow
 				label_date.Text = Catalog.GetString("Undefined");
 			else
 				label_date.Text = dateTime.ToLongDateString();
+
 			//country stuff
 			if(currentPerson.CountryID != Constants.CountryUndefinedID) {
 				string [] countryString = SqliteCountry.Select(currentPerson.CountryID);
+			
 				combo_continents.Active = UtilGtk.ComboMakeActive(continentsTranslated, 
 						Catalog.GetString(countryString[3]));
+				
 				combo_countries.Active = UtilGtk.ComboMakeActive(countriesTranslated, 
 						Catalog.GetString(countryString[1]));
 			}
@@ -1346,7 +1352,6 @@ public class PersonAddModifyWindow
 			TextBuffer tb2 = new TextBuffer (new TextTagTable());
 			tb2.Text = myPS.Comments;
 			textview_ps_comments.Buffer = tb2;
-
 		}
 			
 		sport = SqliteSport.Select(mySportID);
@@ -1494,9 +1499,10 @@ public class PersonAddModifyWindow
 	
 	private void on_combo_continents_changed(object o, EventArgs args) {
 		//Console.WriteLine("Changed");
-		
+
 		if(UtilGtk.ComboGetActive(combo_continents) == Catalog.GetString(Constants.ContinentUndefined)) {
-			countries [0] = Constants.CountryUndefinedID + ":" + Constants.CountryUndefined + ":" + Catalog.GetString(Constants.CountryUndefined);
+			countries [0] = Constants.CountryUndefinedID + ":" + 
+				Constants.CountryUndefined + ":" + Catalog.GetString(Constants.CountryUndefined);
 			countriesTranslated = new String[1];
 			countriesTranslated [0] = Catalog.GetString(Constants.CountryUndefined);
 			combo_countries.Sensitive = false;
@@ -1541,7 +1547,7 @@ public class PersonAddModifyWindow
 	private void on_sport_add_accepted (object o, EventArgs args) {
 		genericWin.Button_accept.Clicked -= new EventHandler(on_sport_add_accepted);
 		string newSportName = genericWin.EntrySelected;
-		if(Sqlite.Exists(Constants.SportTable, newSportName) ||
+		if(Sqlite.Exists(false, Constants.SportTable, newSportName) ||
 				newSportName == Catalog.GetString(Constants.SportUndefined) || //let's save problems
 				newSportName == Catalog.GetString(Constants.SportNone)		//let's save problems
 				)
@@ -1577,7 +1583,7 @@ public class PersonAddModifyWindow
 	{
 		bool personExists;
 		if(adding)
-			personExists = Sqlite.Exists (Constants.PersonTable, Util.RemoveTilde(entry1.Text));
+			personExists = Sqlite.Exists (false, Constants.PersonTable, Util.RemoveTilde(entry1.Text));
 		else
 			personExists = SqlitePerson.ExistsAndItsNotMe (currentPerson.UniqueID, Util.RemoveTilde(entry1.Text));
 
@@ -1601,7 +1607,7 @@ public class PersonAddModifyWindow
 			//if weight has changed
 			if(!adding && (double) spinbutton_weight.Value != weightIni) {
 				//see if this person has done jumps with weight
-				string [] myJumpsNormal = SqliteJump.SelectJumps(currentSession.UniqueID, currentPerson.UniqueID, "withWeight", "");
+				string [] myJumpsNormal = SqliteJump.SelectJumps(false, currentSession.UniqueID, currentPerson.UniqueID, "withWeight", "");
 				string [] myJumpsReactive = SqliteJumpRj.SelectJumps(currentSession.UniqueID, currentPerson.UniqueID, "withWeight", "");
 
 				if(myJumpsNormal.Length > 0 || myJumpsReactive.Length > 0) {
@@ -1639,7 +1645,7 @@ public class PersonAddModifyWindow
 		double weight = (double) spinbutton_weight.Value;
 
 		//convert margarias (it's power is calculated using weight and it's written on description)
-		string [] myMargarias = SqliteRun.SelectRuns(currentSession.UniqueID, currentPerson.UniqueID, "Margaria");
+		string [] myMargarias = SqliteRun.SelectRuns(false, currentSession.UniqueID, currentPerson.UniqueID, "Margaria");
 		foreach(string myStr in myMargarias) {
 			string [] margaria = myStr.Split(new char[] {':'});
 			Run mRun = SqliteRun.SelectRunData(Convert.ToInt32(margaria[1]), false);
@@ -1933,7 +1939,7 @@ public class PersonAddMultipleWindow {
 		
 	void checkEntries(int count, string name, double weight) {
 		if(name.Length > 0) {
-			bool personExists = Sqlite.Exists (Constants.PersonTable, Util.RemoveTilde(name));
+			bool personExists = Sqlite.Exists (false, Constants.PersonTable, Util.RemoveTilde(name));
 			if(personExists) {
 				errorExistsString += "[" + (count+1) + "] " + name + "\n";
 			}
@@ -2063,7 +2069,7 @@ public class PersonShowAllEventsWindow {
 	
 	PersonShowAllEventsWindow (Gtk.Window parent, int sessionID, Person currentPerson) {
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "person_show_all_events", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "person_show_all_events", "chronojump");
 		gladeXML.Autoconnect(this);
 		
 		//put an icon to window
