@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2012   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -918,6 +918,7 @@ partial class ChronoJumpWindow
 	[Widget] Gtk.RadioButton extra_window_radio_run_margaria;
 	[Widget] Gtk.RadioButton extra_window_radio_run_shuttle;
 	[Widget] Gtk.RadioButton extra_window_radio_run_zigzag;
+	[Widget] Gtk.RadioButton extra_window_radio_run_t_test;
 	[Widget] Gtk.RadioButton extra_window_radio_run_more;
 
 	//runs interval
@@ -934,6 +935,7 @@ partial class ChronoJumpWindow
 	[Widget] Gtk.RadioButton extra_window_radio_run_interval_by_time;
 	[Widget] Gtk.RadioButton extra_window_radio_run_interval_unlimited;
 	[Widget] Gtk.RadioButton extra_window_radio_run_interval_mtgug;
+	[Widget] Gtk.RadioButton extra_window_radio_run_interval_3l3r;
 	[Widget] Gtk.RadioButton extra_window_radio_run_interval_rsa_test_1;
 	[Widget] Gtk.RadioButton extra_window_radio_run_interval_more;
 
@@ -997,6 +999,7 @@ partial class ChronoJumpWindow
 		else if(extra_window_radio_run_margaria.Active) currentRunType = new RunType("Margaria");
 		else if(extra_window_radio_run_shuttle.Active) currentRunType = new RunType("Agility-Shuttle-Run");
 		else if(extra_window_radio_run_zigzag.Active) currentRunType = new RunType("Agility-ZigZag");
+		else if(extra_window_radio_run_t_test.Active) currentRunType = new RunType("Agility-T-Test");
 
 		extra_window_runs_initialize(currentRunType);
 	}
@@ -1006,7 +1009,7 @@ partial class ChronoJumpWindow
 		previousRunType = currentRunType;
 
 		if(extra_window_radio_run_more.Active) {
-			runsMoreWin = RunsMoreWindow.Show(app1, true);
+			runsMoreWin = RunsMoreWindow.Show(app1, true, currentRunType.Name);
 			runsMoreWin.Button_accept.Clicked += new EventHandler(on_more_runs_accepted);
 			runsMoreWin.Button_cancel.Clicked += new EventHandler(on_more_runs_cancelled);
 			runsMoreWin.Button_selected.Clicked += new EventHandler(on_more_runs_draw_image_test);
@@ -1019,6 +1022,7 @@ partial class ChronoJumpWindow
 		else if(extra_window_radio_run_interval_by_time.Active) currentRunIntervalType = new RunType("byTime");
 		else if(extra_window_radio_run_interval_unlimited.Active) currentRunIntervalType = new RunType("unlimited");
 		else if(extra_window_radio_run_interval_mtgug.Active) currentRunIntervalType = new RunType("MTGUG");
+		else if(extra_window_radio_run_interval_3l3r.Active) currentRunIntervalType = new RunType("Agility-3L3R");
 		//else if(extra_window_radio_run_interval_rsa_test_1.Active) currentRunIntervalType = new RunType("RSA 8-4-R3-5");
 
 		extra_window_runs_interval_initialize(currentRunIntervalType);
@@ -1029,7 +1033,7 @@ partial class ChronoJumpWindow
 		previousRunIntervalType = currentRunIntervalType;
 
 		if(extra_window_radio_run_interval_more.Active) {
-			runsIntervalMoreWin = RunsIntervalMoreWindow.Show(app1, true);
+			runsIntervalMoreWin = RunsIntervalMoreWindow.Show(app1, true, currentRunIntervalType.Name);
 			runsIntervalMoreWin.Button_accept.Clicked += new EventHandler(on_more_runs_interval_accepted);
 			runsIntervalMoreWin.Button_cancel.Clicked += new EventHandler(on_more_runs_interval_cancelled);
 			runsIntervalMoreWin.Button_selected.Clicked += new EventHandler(on_more_runs_interval_draw_image_test);
@@ -1308,12 +1312,13 @@ public class RunsMoreWindow : EventMoreWindow
 	
 	private double selectedDistance;
 	
-	RunsMoreWindow (Gtk.Window parent, bool testOrDelete) {
+	RunsMoreWindow (Gtk.Window parent, bool testOrDelete, string selectedTestOnMainWindow) {
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "jumps_runs_more", null);
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
 		this.testOrDelete = testOrDelete;
+		this.selectedTestOnMainWindow = selectedTestOnMainWindow;
 		
 		if(!testOrDelete)
 			jumps_runs_more.Title = Catalog.GetString("Delete test type defined by user");
@@ -1328,10 +1333,10 @@ public class RunsMoreWindow : EventMoreWindow
 		initializeThings();
 	}
 	
-	static public RunsMoreWindow Show (Gtk.Window parent, bool testOrDelete)
+	static public RunsMoreWindow Show (Gtk.Window parent, bool testOrDelete, string selectedTestOnMainWindow)
 	{
 		if (RunsMoreWindowBox == null) {
-			RunsMoreWindowBox = new RunsMoreWindow (parent, testOrDelete);
+			RunsMoreWindowBox = new RunsMoreWindow (parent, testOrDelete, selectedTestOnMainWindow);
 		}
 		RunsMoreWindowBox.jumps_runs_more.Show ();
 		
@@ -1428,7 +1433,7 @@ public class RunsMoreWindow : EventMoreWindow
 	}
 
 	protected override string [] findTestTypesInSessions() {
-		return SqliteRun.SelectRuns(-1, -1, selectedEventName); 
+		return SqliteRun.SelectRuns(false, -1, -1, selectedEventName); 
 	}
 
 	void on_button_cancel_clicked (object o, EventArgs args)
@@ -1475,13 +1480,14 @@ public class RunsIntervalMoreWindow : EventMoreWindow
 	private bool selectedUnlimited;
 	private string selectedDistancesString;
 	
-	RunsIntervalMoreWindow (Gtk.Window parent, bool testOrDelete) {
+	RunsIntervalMoreWindow (Gtk.Window parent, bool testOrDelete, string selectedTestOnMainWindow) {
 		//the glade window is the same as jumps_more
 		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "jumps_runs_more", null);
+		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "jumps_runs_more", "chronojump");
 		gladeXML.Autoconnect(this);
 		this.parent = parent;
 		this.testOrDelete = testOrDelete;
+		this.selectedTestOnMainWindow = selectedTestOnMainWindow;
 		
 		if(!testOrDelete)
 			jumps_runs_more.Title = Catalog.GetString("Delete test type defined by user");
@@ -1497,10 +1503,10 @@ public class RunsIntervalMoreWindow : EventMoreWindow
 		initializeThings();
 	}
 	
-	static public RunsIntervalMoreWindow Show (Gtk.Window parent, bool testOrDelete)
+	static public RunsIntervalMoreWindow Show (Gtk.Window parent, bool testOrDelete, string selectedTestOnMainWindow)
 	{
 		if (RunsIntervalMoreWindowBox == null) {
-			RunsIntervalMoreWindowBox = new RunsIntervalMoreWindow (parent, testOrDelete);
+			RunsIntervalMoreWindowBox = new RunsIntervalMoreWindow (parent, testOrDelete, selectedTestOnMainWindow);
 		}
 		RunsIntervalMoreWindowBox.jumps_runs_more.Show ();
 		
