@@ -166,6 +166,11 @@ public class UtilEncoder
 				Util.GetDataDir(), "encoder", Constants.EncoderScriptInertiaMomentum);
 	}
 	
+	public static string GetEncoderScriptNeuromuscularProfile() {
+		return System.IO.Path.Combine(
+				Util.GetDataDir(), "encoder", Constants.EncoderScriptNeuromuscularProfile);
+	}
+	
 	public static string GetEncoderScriptUtilR() {
 		return System.IO.Path.Combine(
 				Util.GetDataDir(), "encoder", Constants.EncoderScriptUtilR);
@@ -236,7 +241,7 @@ public class UtilEncoder
 	}
 	*/
 	
-	public static bool RunEncoderGraph(string title, EncoderStruct es) 
+	public static bool RunEncoderGraph(string title, EncoderStruct es, bool neuromuscularProfileDo) 
 	{
 		CancelRScript = false;
 
@@ -249,6 +254,12 @@ public class UtilEncoder
 		pinfo = new ProcessStartInfo();
 
 		string operatingSystem = "Linux";
+		
+		string scriptUtilR = GetEncoderScriptUtilR();
+
+		string scriptNeuromuscularProfile = "none"; //cannot be blank
+		if(neuromuscularProfileDo)
+			scriptNeuromuscularProfile = GetEncoderScriptNeuromuscularProfile();
 			
 		pBin="Rscript";
 		//pBin="R";
@@ -264,6 +275,8 @@ public class UtilEncoder
 			es.OutputData1 = es.OutputData1.Replace("\\","/");
 			es.OutputData2 = es.OutputData2.Replace("\\","/");
 			es.SpecialData = es.SpecialData.Replace("\\","/");
+			scriptUtilR = scriptUtilR.Replace("\\","/");
+			scriptNeuromuscularProfile = scriptNeuromuscularProfile.Replace("\\","/");
 			operatingSystem = "Windows";
 		}
 		
@@ -271,7 +284,8 @@ public class UtilEncoder
 		string scriptOptions = es.InputData + "\n" + 
 		es.OutputGraph + "\n" + es.OutputData1 + "\n" + 
 		es.OutputData2 + "\n" + es.SpecialData + "\n" + 
-		es.Ep.ToString2("\n") + "\n" + title + "\n" + operatingSystem + "\n";
+		es.Ep.ToString2("\n") + "\n" + title + "\n" + operatingSystem + "\n" +
+		scriptUtilR + "\n" + scriptNeuromuscularProfile + "\n" ;
 
 		string optionsFile = Path.GetTempPath() + "Roptions.txt";
 		TextWriter writer = File.CreateText(optionsFile);
@@ -387,6 +401,9 @@ public class UtilEncoder
 		string inputData = GetEncoderDataTempFileName();
 		string outputData = GetEncoderSpecialDataTempFileName();
 		string operatingSystem = "Linux";
+		
+		string scriptUtilR = GetEncoderScriptUtilR();
+
 			
 		pBin="Rscript";
 		if (UtilAll.IsWindows()) {
@@ -397,6 +414,7 @@ public class UtilEncoder
 			//On win32 R understands backlash as an escape character and 
 			//a file path uses Unix-like path separator '/'		
 			inputData = inputData.Replace("\\","/");
+			scriptUtilR = scriptUtilR.Replace("\\","/");
 			operatingSystem = "Windows";
 		}
 		
@@ -405,7 +423,8 @@ public class UtilEncoder
 			inputData + "\n" + 
 			outputData + "\n" + 
 			Util.ConvertToPoint(weight) + "\n" + 
-			Util.ConvertToPoint(length) + "\n";
+			Util.ConvertToPoint(length) + "\n" +
+			scriptUtilR + "\n";
 
 		string optionsFile = Path.GetTempPath() + "Roptions.txt";
 		TextWriter writer = File.CreateText(optionsFile);
@@ -504,12 +523,68 @@ public class UtilEncoder
 		((IDisposable)writer).Dispose();
 	}
 
-	public static string EncoderSaveCurve(string fileNameSignal, int start, int duration, 
+	public static string EncoderSaveCurve(string fileNameSignal, 
+			int start, int duration, 
+			int inertialCheckStart, int inertialCheckDuration, 
+			bool inertialCheckPositive, //has to be positive (true) or negative (false)
 			int sessionID, int uniqueID, string personName, string timeStamp, int curveIDMax) 
 	{
 		string contents = Util.ReadFile(fileNameSignal, false);
-		string [] startAndDuration = encoderFindPos(contents, start, duration);
+		
+			
+		/*
+		 * at inertial signals, first curve is eccentric (can be to left or right, maybe positive or negative)
+		 * graph.R manages correctly this
+		 * But, when saved a curve, eg. concentric this can be positive or negative
+		 * (depending on the rotating sign of inertial machine at that curve)
+		 * if it's concentric, and it's full of -1,-2,... we have to change sign
+		 * if it's eccentric-concentric, and in the eccentric phase is positive, then we should change sign of both phases
+		 */
+		bool reverseSign = false;
+		if(inertialCheckStart != 0 && inertialCheckDuration != 0) {
+			string [] startAndDurationCheckInertial = encoderFindPos(contents, inertialCheckStart, inertialCheckDuration);
+			string contentsCheckInertial = contents.Substring(
+					Convert.ToInt32(startAndDurationCheckInertial[0]), 
+					Convert.ToInt32(startAndDurationCheckInertial[1])-1); //-1 is for not ending file with a comma
+			
+			//see mean of contentsCheckInertial
+			int sum = 0;
+			int count = 0;
+			using (StringReader reader = new StringReader (contentsCheckInertial)) {
+				do {
+					string line = reader.ReadLine ();
+					if (line == null)
+						break;
 
+					string [] values = line.Split(new char[] {','});
+					foreach(string str in values) {
+						if (str == null || str == "" || str == " ")
+							break;
+
+						//Log.Write ("(" + str + ":");
+						int num = Convert.ToInt32(str);
+						//Log.Write (num.ToString() + ")");
+						sum += num;
+						count ++;
+					}
+				} while(true);
+				
+				if(sum == 0 || count == 0) 
+					Log.WriteLine("inertial check == 0, no data");
+				else {
+					double average = sum * 1.0 / count * 1.0;
+					Log.WriteLine("inertial check == " + average.ToString());
+					if( 
+							(average < 0 && inertialCheckPositive) ||
+							(average > 0 && ! inertialCheckPositive) ) {
+						reverseSign = true;
+					}
+				}
+			}
+		}
+
+
+		string [] startAndDuration = encoderFindPos(contents, start, duration);
 		contents = contents.Substring(
 				Convert.ToInt32(startAndDuration[0]), 
 				Convert.ToInt32(startAndDuration[1])-1); //-1 is for not ending file with a comma
@@ -519,10 +594,37 @@ public class UtilEncoder
 		//in the meantime this NA in reading in graph.R has been deleted
 		//dataTempFile  = dataTempFile[!is.na(dataTempFile)]
 		
-
 		string fileCurve = uniqueID.ToString() + "-" + personName + "-" + 
 			(++ curveIDMax).ToString() + "-" + timeStamp + ".txt";
 		string fileCurveFull = GetEncoderSessionDataCurveDir(sessionID) + Path.DirectorySeparatorChar + fileCurve;
+
+
+		if(reverseSign) {
+			Log.WriteLine("reversingSign");
+			string contentsReversed = "";
+			string sep = "";
+			using (StringReader reader = new StringReader (contents)) {
+				do {
+					string line = reader.ReadLine ();
+					if (line == null)
+						break;
+
+					string [] values = line.Split(new char[] {','});
+					foreach(string str in values) {
+						if (str == null || str == "" || str == " ")
+							break;
+
+						//Log.Write ("(" + str + ":");
+						int num = Convert.ToInt32(str) * -1;
+						//Log.Write (num.ToString() + ")");
+						contentsReversed += sep + num.ToString();
+						sep = ", ";
+					}
+				} while(true);
+			}
+			contents = contentsReversed;
+		}
+
 		
 		TextWriter writer = File.CreateText(fileCurveFull);
 		writer.Write(contents);
